mdt\.gui\.model\_fit\.tabs package
==================================

Submodules
----------

mdt\.gui\.model\_fit\.tabs\.fit\_model\_tab module
--------------------------------------------------

.. automodule:: mdt.gui.model_fit.tabs.fit_model_tab
    :members:
    :undoc-members:
    :show-inheritance:

mdt\.gui\.model\_fit\.tabs\.generate\_brain\_mask\_tab module
-------------------------------------------------------------

.. automodule:: mdt.gui.model_fit.tabs.generate_brain_mask_tab
    :members:
    :undoc-members:
    :show-inheritance:

mdt\.gui\.model\_fit\.tabs\.generate\_protocol\_tab module
----------------------------------------------------------

.. automodule:: mdt.gui.model_fit.tabs.generate_protocol_tab
    :members:
    :undoc-members:
    :show-inheritance:

mdt\.gui\.model\_fit\.tabs\.generate\_roi\_mask\_tab module
-----------------------------------------------------------

.. automodule:: mdt.gui.model_fit.tabs.generate_roi_mask_tab
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: mdt.gui.model_fit.tabs
    :members:
    :undoc-members:
    :show-inheritance:
